# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: model-init.j2

"""Auto-generated package that contains models used by the AccelByte Gaming Services Ugc Service."""

__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

from .models_add_download_count_response import ModelsAddDownloadCountResponse
from .models_admin_content_request_v2 import ModelsAdminContentRequestV2
from .models_admin_get_content_bulk_request import ModelsAdminGetContentBulkRequest
from .models_admin_update_content_request import ModelsAdminUpdateContentRequest
from .models_admin_update_content_request_v2 import ModelsAdminUpdateContentRequestV2
from .models_approve_staging_content_request import ModelsApproveStagingContentRequest
from .models_channel_request import ModelsChannelRequest
from .models_channel_response import ModelsChannelResponse
from .models_config_response import ModelsConfigResponse
from .models_content_downloader_response import ModelsContentDownloaderResponse
from .models_content_download_response import ModelsContentDownloadResponse
from .models_content_download_response_v2 import ModelsContentDownloadResponseV2
from .models_content_like_request import ModelsContentLikeRequest
from .models_content_like_response import ModelsContentLikeResponse
from .models_content_likers_response import ModelsContentLikersResponse
from .models_content_request_v2 import ModelsContentRequestV2
from .models_content_snapshot import ModelsContentSnapshot
from .models_content_version_response import ModelsContentVersionResponse
from .models_copy_content_request import ModelsCopyContentRequest
from .models_create_content_request import ModelsCreateContentRequest
from .models_create_content_request_s3 import ModelsCreateContentRequestS3
from .models_create_content_response import ModelsCreateContentResponse
from .models_create_content_response import (
    ContentStatusEnum as ModelsCreateContentResponseContentStatusEnum,
)
from .models_create_content_response_v2 import ModelsCreateContentResponseV2
from .models_create_content_response_v2 import (
    ContentStatusEnum as ModelsCreateContentResponseV2ContentStatusEnum,
)
from .models_create_group_request import ModelsCreateGroupRequest
from .models_create_group_response import ModelsCreateGroupResponse
from .models_create_screenshot_request import ModelsCreateScreenshotRequest
from .models_create_screenshot_request_item import ModelsCreateScreenshotRequestItem
from .models_create_screenshot_request_item import (
    FileExtensionEnum as ModelsCreateScreenshotRequestItemFileExtensionEnum,
)
from .models_create_screenshot_response import ModelsCreateScreenshotResponse
from .models_create_tag_request import ModelsCreateTagRequest
from .models_create_tag_response import ModelsCreateTagResponse
from .models_create_type_request import ModelsCreateTypeRequest
from .models_create_type_response import ModelsCreateTypeResponse
from .models_creator_follow_state import ModelsCreatorFollowState
from .models_creator_overview_response import ModelsCreatorOverviewResponse
from .models_creator_response import ModelsCreatorResponse
from .models_generate_content_upload_url_request import (
    ModelsGenerateContentUploadURLRequest,
)
from .models_generate_content_upload_url_response import (
    ModelsGenerateContentUploadURLResponse,
)
from .models_get_content_bulk_by_share_codes_request import (
    ModelsGetContentBulkByShareCodesRequest,
)
from .models_get_content_preview_response import ModelsGetContentPreviewResponse
from .models_hide_content_request import ModelsHideContentRequest
from .models_like_state import ModelsLikeState
from .models_list_content_versions_response import ModelsListContentVersionsResponse
from .models_paginated_content_downloader_response import (
    ModelsPaginatedContentDownloaderResponse,
)
from .models_paginated_content_download_response import (
    ModelsPaginatedContentDownloadResponse,
)
from .models_paginated_content_download_response_v2 import (
    ModelsPaginatedContentDownloadResponseV2,
)
from .models_paginated_content_likers_response import (
    ModelsPaginatedContentLikersResponse,
)
from .models_paginated_creator_overview_response import (
    ModelsPaginatedCreatorOverviewResponse,
)
from .models_paginated_get_channel_response import ModelsPaginatedGetChannelResponse
from .models_paginated_get_configs_response import ModelsPaginatedGetConfigsResponse
from .models_paginated_get_tag_response import ModelsPaginatedGetTagResponse
from .models_paginated_get_type_response import ModelsPaginatedGetTypeResponse
from .models_paginated_group_response import ModelsPaginatedGroupResponse
from .models_paginated_list_staging_content_response import (
    ModelsPaginatedListStagingContentResponse,
)
from .models_paging_cursor import ModelsPagingCursor
from .models_payload_url import ModelsPayloadURL
from .models_preview_metadata import ModelsPreviewMetadata
from .models_preview_url import ModelsPreviewURL
from .models_public_channel_request import ModelsPublicChannelRequest
from .models_public_create_content_request_s3 import ModelsPublicCreateContentRequestS3
from .models_public_get_content_bulk_request import ModelsPublicGetContentBulkRequest
from .models_screenshot_response import ModelsScreenshotResponse
from .models_staging_content_response import ModelsStagingContentResponse
from .models_staging_content_response import (
    StatusEnum as ModelsStagingContentResponseStatusEnum,
)
from .models_update_channel_request import ModelsUpdateChannelRequest
from .models_update_config_request import ModelsUpdateConfigRequest
from .models_update_content_request import ModelsUpdateContentRequest
from .models_update_content_request_v2 import ModelsUpdateContentRequestV2
from .models_update_content_response_v2 import ModelsUpdateContentResponseV2
from .models_update_content_response_v2 import (
    ContentStatusEnum as ModelsUpdateContentResponseV2ContentStatusEnum,
)
from .models_update_content_share_code_request import (
    ModelsUpdateContentShareCodeRequest,
)
from .models_update_file_location_request import ModelsUpdateFileLocationRequest
from .models_update_screenshot import ModelsUpdateScreenshot
from .models_update_screenshot_request import ModelsUpdateScreenshotRequest
from .models_update_screenshot_response import ModelsUpdateScreenshotResponse
from .models_update_staging_content_request import ModelsUpdateStagingContentRequest
from .models_user_follow_request import ModelsUserFollowRequest
from .models_user_follow_response import ModelsUserFollowResponse
from .response_error import ResponseError



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: wrapper.j2

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from typing import Any, Dict, List, Optional, Tuple, Union

from accelbyte_py_sdk.core import HeaderStr
from accelbyte_py_sdk.core import get_namespace as get_services_namespace
from accelbyte_py_sdk.core import run_request
from accelbyte_py_sdk.core import run_request_async
from accelbyte_py_sdk.core import same_doc_as

from ..models import ModelsChannelResponse
from ..models import ModelsPaginatedGetChannelResponse
from ..models import ModelsPublicChannelRequest
from ..models import ModelsUpdateChannelRequest
from ..models import ResponseError

from ..operations.public_channel import DeleteChannel
from ..operations.public_channel import GetChannels
from ..operations.public_channel import PublicCreateChannel
from ..operations.public_channel import UpdateChannel


@same_doc_as(DeleteChannel)
def delete_channel(
    channel_id: str,
    user_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs,
):
    """Delete Channel (DeleteChannel)

    Delete user channel

    Properties:
        url: /ugc/v1/public/namespaces/{namespace}/users/{userId}/channels/{channelId}

        method: DELETE

        tags: ["Public Channel"]

        consumes: ["application/json", "application/octet-stream"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        channel_id: (channelId) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

    Responses:
        204: No Content - (Channel deleted)

        401: Unauthorized - ResponseError (20001: unauthorized access)

        404: Not Found - ResponseError (772502: Channel not found)

        500: Internal Server Error - ResponseError (772501: Unable to delete channel)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = DeleteChannel.create(
        channel_id=channel_id,
        user_id=user_id,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(DeleteChannel)
async def delete_channel_async(
    channel_id: str,
    user_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs,
):
    """Delete Channel (DeleteChannel)

    Delete user channel

    Properties:
        url: /ugc/v1/public/namespaces/{namespace}/users/{userId}/channels/{channelId}

        method: DELETE

        tags: ["Public Channel"]

        consumes: ["application/json", "application/octet-stream"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        channel_id: (channelId) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

    Responses:
        204: No Content - (Channel deleted)

        401: Unauthorized - ResponseError (20001: unauthorized access)

        404: Not Found - ResponseError (772502: Channel not found)

        500: Internal Server Error - ResponseError (772501: Unable to delete channel)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = DeleteChannel.create(
        channel_id=channel_id,
        user_id=user_id,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(GetChannels)
def get_channels(
    user_id: str,
    limit: Optional[int] = None,
    name: Optional[str] = None,
    offset: Optional[int] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs,
):
    """Get Channels (GetChannels)

    Get user channel paginated

    Properties:
        url: /ugc/v1/public/namespaces/{namespace}/users/{userId}/channels

        method: GET

        tags: ["Public Channel"]

        consumes: ["application/json", "application/octet-stream"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

        limit: (limit) OPTIONAL int in query

        name: (name) OPTIONAL str in query

        offset: (offset) OPTIONAL int in query

    Responses:
        200: OK - ModelsPaginatedGetChannelResponse (Channel in namespace-level retrieved)

        400: Bad Request - ResponseError (770702: invalid paging parameter)

        401: Unauthorized - ResponseError (20001: unauthorized access)

        500: Internal Server Error - ResponseError (770700: Unable get user channels)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = GetChannels.create(
        user_id=user_id,
        limit=limit,
        name=name,
        offset=offset,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(GetChannels)
async def get_channels_async(
    user_id: str,
    limit: Optional[int] = None,
    name: Optional[str] = None,
    offset: Optional[int] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs,
):
    """Get Channels (GetChannels)

    Get user channel paginated

    Properties:
        url: /ugc/v1/public/namespaces/{namespace}/users/{userId}/channels

        method: GET

        tags: ["Public Channel"]

        consumes: ["application/json", "application/octet-stream"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

        limit: (limit) OPTIONAL int in query

        name: (name) OPTIONAL str in query

        offset: (offset) OPTIONAL int in query

    Responses:
        200: OK - ModelsPaginatedGetChannelResponse (Channel in namespace-level retrieved)

        400: Bad Request - ResponseError (770702: invalid paging parameter)

        401: Unauthorized - ResponseError (20001: unauthorized access)

        500: Internal Server Error - ResponseError (770700: Unable get user channels)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = GetChannels.create(
        user_id=user_id,
        limit=limit,
        name=name,
        offset=offset,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(PublicCreateChannel)
def public_create_channel(
    body: ModelsPublicChannelRequest,
    user_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs,
):
    """Create Channel (PublicCreateChannel)

    Create user channel

    Properties:
        url: /ugc/v1/public/namespaces/{namespace}/users/{userId}/channels

        method: POST

        tags: ["Public Channel"]

        consumes: ["application/json", "application/octet-stream"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ModelsPublicChannelRequest in body

        namespace: (namespace) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

    Responses:
        201: Created - ModelsChannelResponse (channel created)

        400: Bad Request - ResponseError (770500: Invalid request body)

        401: Unauthorized - ResponseError (20001: unauthorized access)

        500: Internal Server Error - ResponseError (770502: Unable to save channel)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = PublicCreateChannel.create(
        body=body,
        user_id=user_id,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(PublicCreateChannel)
async def public_create_channel_async(
    body: ModelsPublicChannelRequest,
    user_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs,
):
    """Create Channel (PublicCreateChannel)

    Create user channel

    Properties:
        url: /ugc/v1/public/namespaces/{namespace}/users/{userId}/channels

        method: POST

        tags: ["Public Channel"]

        consumes: ["application/json", "application/octet-stream"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ModelsPublicChannelRequest in body

        namespace: (namespace) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

    Responses:
        201: Created - ModelsChannelResponse (channel created)

        400: Bad Request - ResponseError (770500: Invalid request body)

        401: Unauthorized - ResponseError (20001: unauthorized access)

        500: Internal Server Error - ResponseError (770502: Unable to save channel)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = PublicCreateChannel.create(
        body=body,
        user_id=user_id,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(UpdateChannel)
def update_channel(
    body: ModelsUpdateChannelRequest,
    channel_id: str,
    user_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs,
):
    """Update Channel (UpdateChannel)

    Update user channel

    Properties:
        url: /ugc/v1/public/namespaces/{namespace}/users/{userId}/channels/{channelId}

        method: PUT

        tags: ["Public Channel"]

        consumes: ["application/json", "application/octet-stream"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ModelsUpdateChannelRequest in body

        channel_id: (channelId) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

    Responses:
        200: OK - ModelsChannelResponse (Channel updated)

        400: Bad Request - ResponseError (770600: Invalid request body)

        401: Unauthorized - ResponseError (20001: unauthorized access)

        404: Not Found - ResponseError (770603: Channel was not found)

        500: Internal Server Error - ResponseError (770602: Unable to save channel)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = UpdateChannel.create(
        body=body,
        channel_id=channel_id,
        user_id=user_id,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(UpdateChannel)
async def update_channel_async(
    body: ModelsUpdateChannelRequest,
    channel_id: str,
    user_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs,
):
    """Update Channel (UpdateChannel)

    Update user channel

    Properties:
        url: /ugc/v1/public/namespaces/{namespace}/users/{userId}/channels/{channelId}

        method: PUT

        tags: ["Public Channel"]

        consumes: ["application/json", "application/octet-stream"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ModelsUpdateChannelRequest in body

        channel_id: (channelId) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

    Responses:
        200: OK - ModelsChannelResponse (Channel updated)

        400: Bad Request - ResponseError (770600: Invalid request body)

        401: Unauthorized - ResponseError (20001: unauthorized access)

        404: Not Found - ResponseError (770603: Channel was not found)

        500: Internal Server Error - ResponseError (770602: Unable to save channel)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = UpdateChannel.create(
        body=body,
        channel_id=channel_id,
        user_id=user_id,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: wrapper.j2

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from typing import Any, Dict, List, Optional, Tuple, Union

from accelbyte_py_sdk.core import HeaderStr
from accelbyte_py_sdk.core import get_namespace as get_services_namespace
from accelbyte_py_sdk.core import run_request
from accelbyte_py_sdk.core import run_request_async
from accelbyte_py_sdk.core import same_doc_as

from ..models import ModelsApproveStagingContentRequest
from ..models import ModelsPaginatedListStagingContentResponse
from ..models import ModelsStagingContentResponse
from ..models import ResponseError

from ..operations.admin_staging_content import AdminApproveStagingContent
from ..operations.admin_staging_content import AdminGetStagingContentByID
from ..operations.admin_staging_content import AdminListStagingContents
from ..operations.admin_staging_content import AdminListUserStagingContents
from ..models import ModelsStagingContentResponseStatusEnum


@same_doc_as(AdminApproveStagingContent)
def admin_approve_staging_content(
    body: ModelsApproveStagingContentRequest,
    content_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs,
):
    """Approve or reject content (AdminApproveStagingContent)

    Approved content will shown to public player. Rejected content stays in staging area and couldn't be seen by other player

    Properties:
        url: /ugc/v2/admin/namespaces/{namespace}/staging-contents/{contentId}/approve

        method: POST

        tags: ["Admin Staging Content"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ModelsApproveStagingContentRequest in body

        content_id: (contentId) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - ModelsStagingContentResponse (content approval created)

        400: Bad Request - ResponseError (774405: Invalid request body)

        401: Unauthorized - ResponseError (20001: unauthorized access)

        403: Forbidden - ResponseError (20013: insufficient permission)

        404: Not Found - ResponseError (774406: staging content not found)

        500: Internal Server Error - ResponseError (774407: unable to approve staging content | 774408: nable to save ugc content: shareCode exceed the limit)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = AdminApproveStagingContent.create(
        body=body,
        content_id=content_id,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AdminApproveStagingContent)
async def admin_approve_staging_content_async(
    body: ModelsApproveStagingContentRequest,
    content_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs,
):
    """Approve or reject content (AdminApproveStagingContent)

    Approved content will shown to public player. Rejected content stays in staging area and couldn't be seen by other player

    Properties:
        url: /ugc/v2/admin/namespaces/{namespace}/staging-contents/{contentId}/approve

        method: POST

        tags: ["Admin Staging Content"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ModelsApproveStagingContentRequest in body

        content_id: (contentId) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - ModelsStagingContentResponse (content approval created)

        400: Bad Request - ResponseError (774405: Invalid request body)

        401: Unauthorized - ResponseError (20001: unauthorized access)

        403: Forbidden - ResponseError (20013: insufficient permission)

        404: Not Found - ResponseError (774406: staging content not found)

        500: Internal Server Error - ResponseError (774407: unable to approve staging content | 774408: nable to save ugc content: shareCode exceed the limit)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = AdminApproveStagingContent.create(
        body=body,
        content_id=content_id,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(AdminGetStagingContentByID)
def admin_get_staging_content_by_id(
    content_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs,
):
    """Get staging content by id (AdminGetStagingContentByID)

    Get staging content by ID

    Properties:
        url: /ugc/v2/admin/namespaces/{namespace}/staging-contents/{contentId}

        method: GET

        tags: ["Admin Staging Content"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        content_id: (contentId) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - ModelsStagingContentResponse (staging content)

        401: Unauthorized - ResponseError (20001: unauthorized access)

        403: Forbidden - ResponseError (20013: insufficient permission)

        404: Not Found - ResponseError (774401: staging content not found)

        500: Internal Server Error - ResponseError (774402: unable to get staging content | 774403: unable to generate presigned URL)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = AdminGetStagingContentByID.create(
        content_id=content_id,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AdminGetStagingContentByID)
async def admin_get_staging_content_by_id_async(
    content_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs,
):
    """Get staging content by id (AdminGetStagingContentByID)

    Get staging content by ID

    Properties:
        url: /ugc/v2/admin/namespaces/{namespace}/staging-contents/{contentId}

        method: GET

        tags: ["Admin Staging Content"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        content_id: (contentId) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - ModelsStagingContentResponse (staging content)

        401: Unauthorized - ResponseError (20001: unauthorized access)

        403: Forbidden - ResponseError (20013: insufficient permission)

        404: Not Found - ResponseError (774401: staging content not found)

        500: Internal Server Error - ResponseError (774402: unable to get staging content | 774403: unable to generate presigned URL)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = AdminGetStagingContentByID.create(
        content_id=content_id,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(AdminListStagingContents)
def admin_list_staging_contents(
    limit: Optional[int] = None,
    offset: Optional[int] = None,
    sort_by: Optional[str] = None,
    status: Optional[str] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs,
):
    """List staging contents (AdminListStagingContents)

    List content that need admin's approval

    Properties:
        url: /ugc/v2/admin/namespaces/{namespace}/staging-contents

        method: GET

        tags: ["Admin Staging Content"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        limit: (limit) OPTIONAL int in query

        offset: (offset) OPTIONAL int in query

        sort_by: (sortBy) OPTIONAL str in query

        status: (status) OPTIONAL str in query

    Responses:
        200: OK - ModelsPaginatedListStagingContentResponse (list user's staging content)

        400: Bad Request - ResponseError (774301: invalid paging parameter)

        401: Unauthorized - ResponseError (20001: unauthorized access)

        403: Forbidden - ResponseError (20013: insufficient permission)

        500: Internal Server Error - ResponseError (774302: unable to get staging content | 774303: unable to generate presigned URL)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = AdminListStagingContents.create(
        limit=limit,
        offset=offset,
        sort_by=sort_by,
        status=status,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AdminListStagingContents)
async def admin_list_staging_contents_async(
    limit: Optional[int] = None,
    offset: Optional[int] = None,
    sort_by: Optional[str] = None,
    status: Optional[str] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs,
):
    """List staging contents (AdminListStagingContents)

    List content that need admin's approval

    Properties:
        url: /ugc/v2/admin/namespaces/{namespace}/staging-contents

        method: GET

        tags: ["Admin Staging Content"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        limit: (limit) OPTIONAL int in query

        offset: (offset) OPTIONAL int in query

        sort_by: (sortBy) OPTIONAL str in query

        status: (status) OPTIONAL str in query

    Responses:
        200: OK - ModelsPaginatedListStagingContentResponse (list user's staging content)

        400: Bad Request - ResponseError (774301: invalid paging parameter)

        401: Unauthorized - ResponseError (20001: unauthorized access)

        403: Forbidden - ResponseError (20013: insufficient permission)

        500: Internal Server Error - ResponseError (774302: unable to get staging content | 774303: unable to generate presigned URL)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = AdminListStagingContents.create(
        limit=limit,
        offset=offset,
        sort_by=sort_by,
        status=status,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(AdminListUserStagingContents)
def admin_list_user_staging_contents(
    user_id: str,
    limit: Optional[int] = None,
    offset: Optional[int] = None,
    sort_by: Optional[str] = None,
    status: Optional[str] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs,
):
    """List user staging contents (AdminListUserStagingContents)

    List user content's that need admin approval

    Properties:
        url: /ugc/v2/admin/namespaces/{namespace}/users/{userId}/staging-contents

        method: GET

        tags: ["Admin Staging Content"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

        limit: (limit) OPTIONAL int in query

        offset: (offset) OPTIONAL int in query

        sort_by: (sortBy) OPTIONAL str in query

        status: (status) OPTIONAL str in query

    Responses:
        200: OK - ModelsPaginatedListStagingContentResponse (list user's staging content)

        400: Bad Request - ResponseError (774301: invalid paging parameter)

        401: Unauthorized - ResponseError (20001: unauthorized access)

        403: Forbidden - ResponseError (20013: insufficient permission)

        500: Internal Server Error - ResponseError (774302: unable to get staging content | 774303: unable to generate presigned URL)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = AdminListUserStagingContents.create(
        user_id=user_id,
        limit=limit,
        offset=offset,
        sort_by=sort_by,
        status=status,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AdminListUserStagingContents)
async def admin_list_user_staging_contents_async(
    user_id: str,
    limit: Optional[int] = None,
    offset: Optional[int] = None,
    sort_by: Optional[str] = None,
    status: Optional[str] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs,
):
    """List user staging contents (AdminListUserStagingContents)

    List user content's that need admin approval

    Properties:
        url: /ugc/v2/admin/namespaces/{namespace}/users/{userId}/staging-contents

        method: GET

        tags: ["Admin Staging Content"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

        limit: (limit) OPTIONAL int in query

        offset: (offset) OPTIONAL int in query

        sort_by: (sortBy) OPTIONAL str in query

        status: (status) OPTIONAL str in query

    Responses:
        200: OK - ModelsPaginatedListStagingContentResponse (list user's staging content)

        400: Bad Request - ResponseError (774301: invalid paging parameter)

        401: Unauthorized - ResponseError (20001: unauthorized access)

        403: Forbidden - ResponseError (20013: insufficient permission)

        500: Internal Server Error - ResponseError (774302: unable to get staging content | 774303: unable to generate presigned URL)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = AdminListUserStagingContents.create(
        user_id=user_id,
        limit=limit,
        offset=offset,
        sort_by=sort_by,
        status=status,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: wrapper.j2

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from typing import Any, Dict, List, Optional, Tuple, Union

from accelbyte_py_sdk.core import HeaderStr
from accelbyte_py_sdk.core import get_namespace as get_services_namespace
from accelbyte_py_sdk.core import run_request
from accelbyte_py_sdk.core import run_request_async
from accelbyte_py_sdk.core import same_doc_as

from ..models import ModelsContentDownloadResponseV2
from ..models import ModelsContentRequestV2
from ..models import ModelsCreateContentResponseV2
from ..models import ModelsCreateScreenshotRequest
from ..models import ModelsCreateScreenshotResponse
from ..models import ModelsGenerateContentUploadURLRequest
from ..models import ModelsGenerateContentUploadURLResponse
from ..models import ModelsGetContentBulkByShareCodesRequest
from ..models import ModelsPaginatedContentDownloadResponseV2
from ..models import ModelsPublicGetContentBulkRequest
from ..models import ModelsUpdateContentRequestV2
from ..models import ModelsUpdateContentResponseV2
from ..models import ModelsUpdateContentShareCodeRequest
from ..models import ModelsUpdateFileLocationRequest
from ..models import ModelsUpdateScreenshotRequest
from ..models import ModelsUpdateScreenshotResponse
from ..models import ResponseError

from ..operations.public_content_v2 import DeleteContentScreenshotV2
from ..operations.public_content_v2 import PublicBulkGetContentByIDV2
from ..operations.public_content_v2 import PublicCreateContentV2
from ..operations.public_content_v2 import PublicDeleteContentByShareCodeV2
from ..operations.public_content_v2 import PublicDeleteContentV2
from ..operations.public_content_v2 import PublicGenerateContentUploadURLV2
from ..operations.public_content_v2 import PublicGetContentBulkByShareCodesV2
from ..operations.public_content_v2 import PublicGetContentByChannelIDV2
from ..operations.public_content_v2 import PublicGetContentByIDV2
from ..operations.public_content_v2 import PublicGetContentByShareCodeV2
from ..operations.public_content_v2 import PublicGetContentByUserIDV2
from ..operations.public_content_v2 import PublicListContentV2
from ..operations.public_content_v2 import PublicUpdateContentByShareCodeV2
from ..operations.public_content_v2 import PublicUpdateContentFileLocation
from ..operations.public_content_v2 import PublicUpdateContentV2
from ..operations.public_content_v2 import UpdateContentShareCodeV2
from ..operations.public_content_v2 import UpdateScreenshotsV2
from ..operations.public_content_v2 import UploadContentScreenshotV2
from ..models import ModelsCreateContentResponseV2ContentStatusEnum
from ..models import ModelsUpdateContentResponseV2ContentStatusEnum


@same_doc_as(DeleteContentScreenshotV2)
def delete_content_screenshot_v2(
    content_id: str,
    screenshot_id: str,
    user_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs,
):
    """Delete screenshots content (DeleteContentScreenshotV2)

    Delete screenshot from a content

    Properties:
        url: /ugc/v2/public/namespaces/{namespace}/users/{userId}/contents/{contentId}/screenshots/{screenshotId}

        method: DELETE

        tags: ["Public Content V2"]

        consumes: ["application/json", "application/octet-stream"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        content_id: (contentId) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

        screenshot_id: (screenshotId) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

    Responses:
        204: No Content - (Screenshot deleted)

        400: Bad Request - ResponseError (772602: Unable to check user ban status/Unable to get updated ugc content)

        401: Unauthorized - ResponseError (20001: unauthorized access)

        403: Forbidden - ResponseError (772604: User has been banned to update content)

        404: Not Found - ResponseError (772603: Content not found | 772602: Unable to check user ban status/Unable to get updated ugc content)

        500: Internal Server Error - ResponseError (772602: Unable to check user ban status/Unable to get updated ugc content)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = DeleteContentScreenshotV2.create(
        content_id=content_id,
        screenshot_id=screenshot_id,
        user_id=user_id,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(DeleteContentScreenshotV2)
async def delete_content_screenshot_v2_async(
    content_id: str,
    screenshot_id: str,
    user_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs,
):
    """Delete screenshots content (DeleteContentScreenshotV2)

    Delete screenshot from a content

    Properties:
        url: /ugc/v2/public/namespaces/{namespace}/users/{userId}/contents/{contentId}/screenshots/{screenshotId}

        method: DELETE

        tags: ["Public Content V2"]

        consumes: ["application/json", "application/octet-stream"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        content_id: (contentId) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

        screenshot_id: (screenshotId) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

    Responses:
        204: No Content - (Screenshot deleted)

        400: Bad Request - ResponseError (772602: Unable to check user ban status/Unable to get updated ugc content)

        401: Unauthorized - ResponseError (20001: unauthorized access)

        403: Forbidden - ResponseError (772604: User has been banned to update content)

        404: Not Found - ResponseError (772603: Content not found | 772602: Unable to check user ban status/Unable to get updated ugc content)

        500: Internal Server Error - ResponseError (772602: Unable to check user ban status/Unable to get updated ugc content)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = DeleteContentScreenshotV2.create(
        content_id=content_id,
        screenshot_id=screenshot_id,
        user_id=user_id,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(PublicBulkGetContentByIDV2)
def public_bulk_get_content_by_idv2(
    body: ModelsPublicGetContentBulkRequest,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs,
):
    """Get contents by content Ids  (PublicBulkGetContentByIDV2)

    Maximum requested Ids: 100.
    Public user can access without token or if token specified, requires valid user token

    Properties:
        url: /ugc/v2/public/namespaces/{namespace}/contents/bulk

        method: POST

        tags: ["Public Content V2"]

        consumes: ["application/json", "application/octet-stream"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ModelsPublicGetContentBulkRequest in body

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - List[ModelsContentDownloadResponseV2] (Get contents by content Ids)

        400: Bad Request - ResponseError (773900: Malformed request/Invalid request body)

        401: Unauthorized - ResponseError (20001: unauthorized access)

        500: Internal Server Error - ResponseError (770801: Unable to get ugc content: database/Unable to get creator | 773902: Failed generate download URL)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = PublicBulkGetContentByIDV2.create(
        body=body,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(PublicBulkGetContentByIDV2)
async def public_bulk_get_content_by_idv2_async(
    body: ModelsPublicGetContentBulkRequest,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs,
):
    """Get contents by content Ids  (PublicBulkGetContentByIDV2)

    Maximum requested Ids: 100.
    Public user can access without token or if token specified, requires valid user token

    Properties:
        url: /ugc/v2/public/namespaces/{namespace}/contents/bulk

        method: POST

        tags: ["Public Content V2"]

        consumes: ["application/json", "application/octet-stream"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ModelsPublicGetContentBulkRequest in body

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - List[ModelsContentDownloadResponseV2] (Get contents by content Ids)

        400: Bad Request - ResponseError (773900: Malformed request/Invalid request body)

        401: Unauthorized - ResponseError (20001: unauthorized access)

        500: Internal Server Error - ResponseError (770801: Unable to get ugc content: database/Unable to get creator | 773902: Failed generate download URL)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = PublicBulkGetContentByIDV2.create(
        body=body,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(PublicCreateContentV2)
def public_create_content_v2(
    body: ModelsContentRequestV2,
    channel_id: str,
    user_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs,
):
    """Create a content (PublicCreateContentV2)

    Create a new content

    Properties:
        url: /ugc/v2/public/namespaces/{namespace}/users/{userId}/channels/{channelId}/contents

        method: POST

        tags: ["Public Content V2"]

        consumes: ["application/json", "application/octet-stream"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ModelsContentRequestV2 in body

        channel_id: (channelId) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

    Responses:
        201: Created - ModelsCreateContentResponseV2 (Content created)

        400: Bad Request - ResponseError (770100: Malformed request/Invalid request body/channel do not exist)

        401: Unauthorized - ResponseError (20001: unauthorized access)

        404: Not Found - ResponseError (770106: channel doesn't exist)

        500: Internal Server Error - ResponseError (770102: Unable to check user ban status/Unable to save ugc content: unable to get channel | 770105: Unable to save ugc content: failed generate upload URL | 770103: Unable to save ugc content: shareCode exceed the limit)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = PublicCreateContentV2.create(
        body=body,
        channel_id=channel_id,
        user_id=user_id,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(PublicCreateContentV2)
async def public_create_content_v2_async(
    body: ModelsContentRequestV2,
    channel_id: str,
    user_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs,
):
    """Create a content (PublicCreateContentV2)

    Create a new content

    Properties:
        url: /ugc/v2/public/namespaces/{namespace}/users/{userId}/channels/{channelId}/contents

        method: POST

        tags: ["Public Content V2"]

        consumes: ["application/json", "application/octet-stream"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ModelsContentRequestV2 in body

        channel_id: (channelId) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

    Responses:
        201: Created - ModelsCreateContentResponseV2 (Content created)

        400: Bad Request - ResponseError (770100: Malformed request/Invalid request body/channel do not exist)

        401: Unauthorized - ResponseError (20001: unauthorized access)

        404: Not Found - ResponseError (770106: channel doesn't exist)

        500: Internal Server Error - ResponseError (770102: Unable to check user ban status/Unable to save ugc content: unable to get channel | 770105: Unable to save ugc content: failed generate upload URL | 770103: Unable to save ugc content: shareCode exceed the limit)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = PublicCreateContentV2.create(
        body=body,
        channel_id=channel_id,
        user_id=user_id,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(PublicDeleteContentByShareCodeV2)
def public_delete_content_by_share_code_v2(
    channel_id: str,
    share_code: str,
    user_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs,
):
    """Delete content by share code (PublicDeleteContentByShareCodeV2)

    Delete existing content by share code

    Properties:
        url: /ugc/v2/public/namespaces/{namespace}/users/{userId}/channels/{channelId}/contents/sharecodes/{shareCode}

        method: DELETE

        tags: ["Public Content V2"]

        consumes: ["application/json", "application/octet-stream"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        channel_id: (channelId) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

        share_code: (shareCode) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

    Responses:
        204: No Content - (Content deleted)

        401: Unauthorized - ResponseError (20001: unauthorized access)

        404: Not Found - ResponseError (772702: Content not found)

        500: Internal Server Error - ResponseError (772701: Unable to delete content/Unable to update user liked count/Unable to delete like state/Unable to delete like state)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = PublicDeleteContentByShareCodeV2.create(
        channel_id=channel_id,
        share_code=share_code,
        user_id=user_id,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(PublicDeleteContentByShareCodeV2)
async def public_delete_content_by_share_code_v2_async(
    channel_id: str,
    share_code: str,
    user_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs,
):
    """Delete content by share code (PublicDeleteContentByShareCodeV2)

    Delete existing content by share code

    Properties:
        url: /ugc/v2/public/namespaces/{namespace}/users/{userId}/channels/{channelId}/contents/sharecodes/{shareCode}

        method: DELETE

        tags: ["Public Content V2"]

        consumes: ["application/json", "application/octet-stream"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        channel_id: (channelId) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

        share_code: (shareCode) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

    Responses:
        204: No Content - (Content deleted)

        401: Unauthorized - ResponseError (20001: unauthorized access)

        404: Not Found - ResponseError (772702: Content not found)

        500: Internal Server Error - ResponseError (772701: Unable to delete content/Unable to update user liked count/Unable to delete like state/Unable to delete like state)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = PublicDeleteContentByShareCodeV2.create(
        channel_id=channel_id,
        share_code=share_code,
        user_id=user_id,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(PublicDeleteContentV2)
def public_delete_content_v2(
    channel_id: str,
    content_id: str,
    user_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs,
):
    """Delete content (PublicDeleteContentV2)

    Delete existing content

    Properties:
        url: /ugc/v2/public/namespaces/{namespace}/users/{userId}/channels/{channelId}/contents/{contentId}

        method: DELETE

        tags: ["Public Content V2"]

        consumes: ["application/json", "application/octet-stream"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        channel_id: (channelId) REQUIRED str in path

        content_id: (contentId) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

    Responses:
        204: No Content - (Content deleted)

        401: Unauthorized - ResponseError (20001: unauthorized access)

        404: Not Found - ResponseError (772702: Content not found)

        500: Internal Server Error - ResponseError (772701: Unable to delete content/Unable to update user liked count/Unable to delete like state/Unable to delete like state)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = PublicDeleteContentV2.create(
        channel_id=channel_id,
        content_id=content_id,
        user_id=user_id,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(PublicDeleteContentV2)
async def public_delete_content_v2_async(
    channel_id: str,
    content_id: str,
    user_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs,
):
    """Delete content (PublicDeleteContentV2)

    Delete existing content

    Properties:
        url: /ugc/v2/public/namespaces/{namespace}/users/{userId}/channels/{channelId}/contents/{contentId}

        method: DELETE

        tags: ["Public Content V2"]

        consumes: ["application/json", "application/octet-stream"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        channel_id: (channelId) REQUIRED str in path

        content_id: (contentId) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

    Responses:
        204: No Content - (Content deleted)

        401: Unauthorized - ResponseError (20001: unauthorized access)

        404: Not Found - ResponseError (772702: Content not found)

        500: Internal Server Error - ResponseError (772701: Unable to delete content/Unable to update user liked count/Unable to delete like state/Unable to delete like state)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = PublicDeleteContentV2.create(
        channel_id=channel_id,
        content_id=content_id,
        user_id=user_id,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(PublicGenerateContentUploadURLV2)
def public_generate_content_upload_urlv2(
    body: ModelsGenerateContentUploadURLRequest,
    channel_id: str,
    content_id: str,
    user_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs,
):
    """Generate content upload URL (PublicGenerateContentUploadURLV2)

    Generate content upload URL

    Properties:
        url: /ugc/v2/public/namespaces/{namespace}/users/{userId}/channels/{channelId}/contents/{contentId}/uploadUrl

        method: PATCH

        tags: ["Public Content V2"]

        consumes: ["application/json", "application/octet-stream"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ModelsGenerateContentUploadURLRequest in body

        channel_id: (channelId) REQUIRED str in path

        content_id: (contentId) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

    Responses:
        200: OK - ModelsGenerateContentUploadURLResponse (content upload URL generated)

        400: Bad Request - ResponseError (772601: Malformed request)

        401: Unauthorized - ResponseError (20001: unauthorized access)

        403: Forbidden - ResponseError (772604: User has been banned to update content)

        404: Not Found - ResponseError (772603: Content not found)

        500: Internal Server Error - ResponseError (772602: Unable to check user ban status/Unable to get updated ugc content | 772605: Unable to save ugc content: failed generate upload URL)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = PublicGenerateContentUploadURLV2.create(
        body=body,
        channel_id=channel_id,
        content_id=content_id,
        user_id=user_id,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(PublicGenerateContentUploadURLV2)
async def public_generate_content_upload_urlv2_async(
    body: ModelsGenerateContentUploadURLRequest,
    channel_id: str,
    content_id: str,
    user_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs,
):
    """Generate content upload URL (PublicGenerateContentUploadURLV2)

    Generate content upload URL

    Properties:
        url: /ugc/v2/public/namespaces/{namespace}/users/{userId}/channels/{channelId}/contents/{contentId}/uploadUrl

        method: PATCH

        tags: ["Public Content V2"]

        consumes: ["application/json", "application/octet-stream"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ModelsGenerateContentUploadURLRequest in body

        channel_id: (channelId) REQUIRED str in path

        content_id: (contentId) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

    Responses:
        200: OK - ModelsGenerateContentUploadURLResponse (content upload URL generated)

        400: Bad Request - ResponseError (772601: Malformed request)

        401: Unauthorized - ResponseError (20001: unauthorized access)

        403: Forbidden - ResponseError (772604: User has been banned to update content)

        404: Not Found - ResponseError (772603: Content not found)

        500: Internal Server Error - ResponseError (772602: Unable to check user ban status/Unable to get updated ugc content | 772605: Unable to save ugc content: failed generate upload URL)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = PublicGenerateContentUploadURLV2.create(
        body=body,
        channel_id=channel_id,
        content_id=content_id,
        user_id=user_id,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(PublicGetContentBulkByShareCodesV2)
def public_get_content_bulk_by_share_codes_v2(
    body: ModelsGetContentBulkByShareCodesRequest,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs,
):
    """Bulk get content by content sharecodes (PublicGetContentBulkByShareCodesV2)

    Require valid user token.
    Maximum sharecodes per request 100

    Properties:
        url: /ugc/v2/public/namespaces/{namespace}/contents/sharecodes/bulk

        method: POST

        tags: ["Public Content V2"]

        consumes: ["application/json", "application/octet-stream"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ModelsGetContentBulkByShareCodesRequest in body

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - List[ModelsContentDownloadResponseV2] (Bulk get content by content sharecodes)

        400: Bad Request - ResponseError (773900: Malformed request/Invalid request body)

        401: Unauthorized - ResponseError (20001: unauthorized access)

        403: Forbidden - ResponseError (20013: insufficient permission)

        500: Internal Server Error - ResponseError (773901: Unable to get ugc content: database/Unable to get creator | 773902: Failed generate download URL)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = PublicGetContentBulkByShareCodesV2.create(
        body=body,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(PublicGetContentBulkByShareCodesV2)
async def public_get_content_bulk_by_share_codes_v2_async(
    body: ModelsGetContentBulkByShareCodesRequest,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs,
):
    """Bulk get content by content sharecodes (PublicGetContentBulkByShareCodesV2)

    Require valid user token.
    Maximum sharecodes per request 100

    Properties:
        url: /ugc/v2/public/namespaces/{namespace}/contents/sharecodes/bulk

        method: POST

        tags: ["Public Content V2"]

        consumes: ["application/json", "application/octet-stream"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ModelsGetContentBulkByShareCodesRequest in body

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - List[ModelsContentDownloadResponseV2] (Bulk get content by content sharecodes)

        400: Bad Request - ResponseError (773900: Malformed request/Invalid request body)

        401: Unauthorized - ResponseError (20001: unauthorized access)

        403: Forbidden - ResponseError (20013: insufficient permission)

        500: Internal Server Error - ResponseError (773901: Unable to get ugc content: database/Unable to get creator | 773902: Failed generate download URL)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = PublicGetContentBulkByShareCodesV2.create(
        body=body,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(PublicGetContentByChannelIDV2)
def public_get_content_by_channel_idv2(
    channel_id: str,
    limit: Optional[int] = None,
    name: Optional[str] = None,
    offset: Optional[int] = None,
    sort_by: Optional[str] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs,
):
    """List contents specific to a channel (PublicGetContentByChannelIDV2)

    Public user can access without token or if token specified, requires valid user token

    Properties:
        url: /ugc/v2/public/namespaces/{namespace}/channels/{channelId}/contents

        method: GET

        tags: ["Public Content V2"]

        consumes: ["application/json", "application/octet-stream"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        channel_id: (channelId) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

        limit: (limit) OPTIONAL int in query

        name: (name) OPTIONAL str in query

        offset: (offset) OPTIONAL int in query

        sort_by: (sortBy) OPTIONAL str in query

    Responses:
        200: OK - ModelsPaginatedContentDownloadResponseV2 (List content specific to a channel)

        400: Bad Request - ResponseError (770804: invalid paging parameter)

        401: Unauthorized - ResponseError (20001: unauthorized access)

        500: Internal Server Error - ResponseError (770805: Unable to get ugc content: database error)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = PublicGetContentByChannelIDV2.create(
        channel_id=channel_id,
        limit=limit,
        name=name,
        offset=offset,
        sort_by=sort_by,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(PublicGetContentByChannelIDV2)
async def public_get_content_by_channel_idv2_async(
    channel_id: str,
    limit: Optional[int] = None,
    name: Optional[str] = None,
    offset: Optional[int] = None,
    sort_by: Optional[str] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs,
):
    """List contents specific to a channel (PublicGetContentByChannelIDV2)

    Public user can access without token or if token specified, requires valid user token

    Properties:
        url: /ugc/v2/public/namespaces/{namespace}/channels/{channelId}/contents

        method: GET

        tags: ["Public Content V2"]

        consumes: ["application/json", "application/octet-stream"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        channel_id: (channelId) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

        limit: (limit) OPTIONAL int in query

        name: (name) OPTIONAL str in query

        offset: (offset) OPTIONAL int in query

        sort_by: (sortBy) OPTIONAL str in query

    Responses:
        200: OK - ModelsPaginatedContentDownloadResponseV2 (List content specific to a channel)

        400: Bad Request - ResponseError (770804: invalid paging parameter)

        401: Unauthorized - ResponseError (20001: unauthorized access)

        500: Internal Server Error - ResponseError (770805: Unable to get ugc content: database error)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = PublicGetContentByChannelIDV2.create(
        channel_id=channel_id,
        limit=limit,
        name=name,
        offset=offset,
        sort_by=sort_by,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(PublicGetContentByIDV2)
def public_get_content_by_idv2(
    content_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs,
):
    """Get content by content ID (PublicGetContentByIDV2)

    Public user can access without token or if token specified, requires valid user token

    Properties:
        url: /ugc/v2/public/namespaces/{namespace}/contents/{contentId}

        method: GET

        tags: ["Public Content V2"]

        consumes: ["application/json", "application/octet-stream"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        content_id: (contentId) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - ModelsContentDownloadResponseV2 (Get content by content ID)

        401: Unauthorized - ResponseError (20001: unauthorized access)

        404: Not Found - ResponseError (773200: ugc content not found)

        500: Internal Server Error - ResponseError (773201: Unable to get ugc content/Unable to get creator/Unable to get included group | 770301: Unable to get ugc content/Unable to get creator | 773203: Failed generate download URL)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = PublicGetContentByIDV2.create(
        content_id=content_id,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(PublicGetContentByIDV2)
async def public_get_content_by_idv2_async(
    content_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs,
):
    """Get content by content ID (PublicGetContentByIDV2)

    Public user can access without token or if token specified, requires valid user token

    Properties:
        url: /ugc/v2/public/namespaces/{namespace}/contents/{contentId}

        method: GET

        tags: ["Public Content V2"]

        consumes: ["application/json", "application/octet-stream"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        content_id: (contentId) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - ModelsContentDownloadResponseV2 (Get content by content ID)

        401: Unauthorized - ResponseError (20001: unauthorized access)

        404: Not Found - ResponseError (773200: ugc content not found)

        500: Internal Server Error - ResponseError (773201: Unable to get ugc content/Unable to get creator/Unable to get included group | 770301: Unable to get ugc content/Unable to get creator | 773203: Failed generate download URL)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = PublicGetContentByIDV2.create(
        content_id=content_id,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(PublicGetContentByShareCodeV2)
def public_get_content_by_share_code_v2(
    share_code: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs,
):
    """Get content by sharecode (PublicGetContentByShareCodeV2)

    Public user can access without token or if token specified, requires valid user token

    Properties:
        url: /ugc/v2/public/namespaces/{namespace}/contents/sharecodes/{shareCode}

        method: GET

        tags: ["Public Content V2"]

        consumes: ["application/json", "application/octet-stream"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        share_code: (shareCode) REQUIRED str in path

    Responses:
        200: OK - ModelsContentDownloadResponseV2 (Get content by sharecode)

        401: Unauthorized - ResponseError (20001: unauthorized access)

        404: Not Found - ResponseError (770300: ugc content not found)

        500: Internal Server Error - ResponseError (770301: Unable to get ugc content/Unable to get creator | 770303: Failed generate download URL)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = PublicGetContentByShareCodeV2.create(
        share_code=share_code,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(PublicGetContentByShareCodeV2)
async def public_get_content_by_share_code_v2_async(
    share_code: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs,
):
    """Get content by sharecode (PublicGetContentByShareCodeV2)

    Public user can access without token or if token specified, requires valid user token

    Properties:
        url: /ugc/v2/public/namespaces/{namespace}/contents/sharecodes/{shareCode}

        method: GET

        tags: ["Public Content V2"]

        consumes: ["application/json", "application/octet-stream"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        share_code: (shareCode) REQUIRED str in path

    Responses:
        200: OK - ModelsContentDownloadResponseV2 (Get content by sharecode)

        401: Unauthorized - ResponseError (20001: unauthorized access)

        404: Not Found - ResponseError (770300: ugc content not found)

        500: Internal Server Error - ResponseError (770301: Unable to get ugc content/Unable to get creator | 770303: Failed generate download URL)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = PublicGetContentByShareCodeV2.create(
        share_code=share_code,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(PublicGetContentByUserIDV2)
def public_get_content_by_user_idv2(
    user_id: str,
    limit: Optional[int] = None,
    offset: Optional[int] = None,
    sort_by: Optional[str] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs,
):
    """Get content by user ID (PublicGetContentByUserIDV2)

    Public user can access without token or if token specified, required permission NAMESPACE:{namespace}:USER:{userId}:CONTENT [READ].

    Properties:
        url: /ugc/v2/public/namespaces/{namespace}/users/{userId}/contents

        method: GET

        tags: ["Public Content V2"]

        consumes: ["application/json", "application/octet-stream"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

        limit: (limit) OPTIONAL int in query

        offset: (offset) OPTIONAL int in query

        sort_by: (sortBy) OPTIONAL str in query

    Responses:
        200: OK - ModelsPaginatedContentDownloadResponseV2 (Get content by user ID)

        400: Bad Request - ResponseError (770900: invalid paging parameter)

        401: Unauthorized - ResponseError (20001: unauthorized access)

        500: Internal Server Error - ResponseError (770901: Unable to get ugc content: database error/Unable to get creator | 770801: Unable to get ugc content: database/Unable to get creator | 770903: Failed generate download URL)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = PublicGetContentByUserIDV2.create(
        user_id=user_id,
        limit=limit,
        offset=offset,
        sort_by=sort_by,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(PublicGetContentByUserIDV2)
async def public_get_content_by_user_idv2_async(
    user_id: str,
    limit: Optional[int] = None,
    offset: Optional[int] = None,
    sort_by: Optional[str] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs,
):
    """Get content by user ID (PublicGetContentByUserIDV2)

    Public user can access without token or if token specified, required permission NAMESPACE:{namespace}:USER:{userId}:CONTENT [READ].

    Properties:
        url: /ugc/v2/public/namespaces/{namespace}/users/{userId}/contents

        method: GET

        tags: ["Public Content V2"]

        consumes: ["application/json", "application/octet-stream"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

        limit: (limit) OPTIONAL int in query

        offset: (offset) OPTIONAL int in query

        sort_by: (sortBy) OPTIONAL str in query

    Responses:
        200: OK - ModelsPaginatedContentDownloadResponseV2 (Get content by user ID)

        400: Bad Request - ResponseError (770900: invalid paging parameter)

        401: Unauthorized - ResponseError (20001: unauthorized access)

        500: Internal Server Error - ResponseError (770901: Unable to get ugc content: database error/Unable to get creator | 770801: Unable to get ugc content: database/Unable to get creator | 770903: Failed generate download URL)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = PublicGetContentByUserIDV2.create(
        user_id=user_id,
        limit=limit,
        offset=offset,
        sort_by=sort_by,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(PublicListContentV2)
def public_list_content_v2(
    is_official: Optional[bool] = None,
    limit: Optional[int] = None,
    name: Optional[str] = None,
    offset: Optional[int] = None,
    sort_by: Optional[str] = None,
    sub_type: Optional[str] = None,
    tags: Optional[List[str]] = None,
    type_: Optional[str] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs,
):
    """List contents (PublicListContentV2)

    For advance tag filtering supports & as AND operator and | as OR operator and parentheses ( ) for priority. e.g:


    *tags=red*
    *tags=red&animal;*
    *tags=red|animal*
    *tags=red&animal;|wild*
    *tags=red&(animal|wild)*

    The precedence of logical operator is AND > OR, so if no parentheses, AND logical operator will be executed first.

    Allowed character for operand: alphanumeric, underscore _ and dash -

    Allowed character for operator: & | ( )


    **Please note that value of tags query param should be URL encoded**

    Properties:
        url: /ugc/v2/public/namespaces/{namespace}/contents

        method: GET

        tags: ["Public Content V2"]

        consumes: ["application/json", "application/octet-stream"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        is_official: (isOfficial) OPTIONAL bool in query

        limit: (limit) OPTIONAL int in query

        name: (name) OPTIONAL str in query

        offset: (offset) OPTIONAL int in query

        sort_by: (sortBy) OPTIONAL str in query

        sub_type: (subType) OPTIONAL str in query

        tags: (tags) OPTIONAL List[str] in query

        type_: (type) OPTIONAL str in query

    Responses:
        200: OK - ModelsPaginatedContentDownloadResponseV2 (list content's)

        400: Bad Request - ResponseError (770800: invalid paging parameter/max allowed number of tags is {maxTags}/invalid official parameter/invalid ishidden parameter)

        401: Unauthorized - ResponseError (20001: unauthorized access)

        500: Internal Server Error - ResponseError (770801: Unable to get ugc content: database/Unable to get creator | 770803: Failed generate download URL)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = PublicListContentV2.create(
        is_official=is_official,
        limit=limit,
        name=name,
        offset=offset,
        sort_by=sort_by,
        sub_type=sub_type,
        tags=tags,
        type_=type_,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(PublicListContentV2)
async def public_list_content_v2_async(
    is_official: Optional[bool] = None,
    limit: Optional[int] = None,
    name: Optional[str] = None,
    offset: Optional[int] = None,
    sort_by: Optional[str] = None,
    sub_type: Optional[str] = None,
    tags: Optional[List[str]] = None,
    type_: Optional[str] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs,
):
    """List contents (PublicListContentV2)

    For advance tag filtering supports & as AND operator and | as OR operator and parentheses ( ) for priority. e.g:


    *tags=red*
    *tags=red&animal;*
    *tags=red|animal*
    *tags=red&animal;|wild*
    *tags=red&(animal|wild)*

    The precedence of logical operator is AND > OR, so if no parentheses, AND logical operator will be executed first.

    Allowed character for operand: alphanumeric, underscore _ and dash -

    Allowed character for operator: & | ( )


    **Please note that value of tags query param should be URL encoded**

    Properties:
        url: /ugc/v2/public/namespaces/{namespace}/contents

        method: GET

        tags: ["Public Content V2"]

        consumes: ["application/json", "application/octet-stream"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        is_official: (isOfficial) OPTIONAL bool in query

        limit: (limit) OPTIONAL int in query

        name: (name) OPTIONAL str in query

        offset: (offset) OPTIONAL int in query

        sort_by: (sortBy) OPTIONAL str in query

        sub_type: (subType) OPTIONAL str in query

        tags: (tags) OPTIONAL List[str] in query

        type_: (type) OPTIONAL str in query

    Responses:
        200: OK - ModelsPaginatedContentDownloadResponseV2 (list content's)

        400: Bad Request - ResponseError (770800: invalid paging parameter/max allowed number of tags is {maxTags}/invalid official parameter/invalid ishidden parameter)

        401: Unauthorized - ResponseError (20001: unauthorized access)

        500: Internal Server Error - ResponseError (770801: Unable to get ugc content: database/Unable to get creator | 770803: Failed generate download URL)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = PublicListContentV2.create(
        is_official=is_official,
        limit=limit,
        name=name,
        offset=offset,
        sort_by=sort_by,
        sub_type=sub_type,
        tags=tags,
        type_=type_,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(PublicUpdateContentByShareCodeV2)
def public_update_content_by_share_code_v2(
    body: ModelsUpdateContentRequestV2,
    channel_id: str,
    share_code: str,
    user_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs,
):
    """Update content to S3 bucket by share code (PublicUpdateContentByShareCodeV2)

    Update content by share code

    Properties:
        url: /ugc/v2/public/namespaces/{namespace}/users/{userId}/channels/{channelId}/contents/s3/sharecodes/{shareCode}

        method: PUT

        tags: ["Public Content V2"]

        consumes: ["application/json", "application/octet-stream"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ModelsUpdateContentRequestV2 in body

        channel_id: (channelId) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

        share_code: (shareCode) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

    Responses:
        200: OK - ModelsCreateContentResponseV2 (content updated at s3)

        400: Bad Request - ResponseError (772601: Malformed request)

        401: Unauthorized - ResponseError (20001: unauthorized access)

        403: Forbidden - ResponseError (772604: User has been banned to update content)

        404: Not Found - ResponseError (772603: Content not found)

        409: Conflict - ResponseError (772606: Share code already used)

        500: Internal Server Error - ResponseError (772602: Unable to check user ban status/Unable to get updated ugc content)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = PublicUpdateContentByShareCodeV2.create(
        body=body,
        channel_id=channel_id,
        share_code=share_code,
        user_id=user_id,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(PublicUpdateContentByShareCodeV2)
async def public_update_content_by_share_code_v2_async(
    body: ModelsUpdateContentRequestV2,
    channel_id: str,
    share_code: str,
    user_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs,
):
    """Update content to S3 bucket by share code (PublicUpdateContentByShareCodeV2)

    Update content by share code

    Properties:
        url: /ugc/v2/public/namespaces/{namespace}/users/{userId}/channels/{channelId}/contents/s3/sharecodes/{shareCode}

        method: PUT

        tags: ["Public Content V2"]

        consumes: ["application/json", "application/octet-stream"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ModelsUpdateContentRequestV2 in body

        channel_id: (channelId) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

        share_code: (shareCode) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

    Responses:
        200: OK - ModelsCreateContentResponseV2 (content updated at s3)

        400: Bad Request - ResponseError (772601: Malformed request)

        401: Unauthorized - ResponseError (20001: unauthorized access)

        403: Forbidden - ResponseError (772604: User has been banned to update content)

        404: Not Found - ResponseError (772603: Content not found)

        409: Conflict - ResponseError (772606: Share code already used)

        500: Internal Server Error - ResponseError (772602: Unable to check user ban status/Unable to get updated ugc content)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = PublicUpdateContentByShareCodeV2.create(
        body=body,
        channel_id=channel_id,
        share_code=share_code,
        user_id=user_id,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(PublicUpdateContentFileLocation)
def public_update_content_file_location(
    body: ModelsUpdateFileLocationRequest,
    channel_id: str,
    content_id: str,
    user_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs,
):
    """Update content file location (PublicUpdateContentFileLocation)

    This endpoint should be used after calling generate upload url endpoint to commit the changes

    Properties:
        url: /ugc/v2/public/namespaces/{namespace}/users/{userId}/channels/{channelId}/contents/{contentId}/fileLocation

        method: PATCH

        tags: ["Public Content V2"]

        consumes: ["application/json", "application/octet-stream"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ModelsUpdateFileLocationRequest in body

        channel_id: (channelId) REQUIRED str in path

        content_id: (contentId) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

    Responses:
        200: OK - ModelsUpdateContentResponseV2 (Update content file location)

        400: Bad Request - ResponseError (774001: unable to read response body/unable to update file location)

        401: Unauthorized - ResponseError (20001: unauthorized access)

        403: Forbidden - ResponseError (772604: User has been banned to update content | 20013: insufficient permission)

        404: Not Found - ResponseError (774002: unable to update content file location: content not found)

        500: Internal Server Error - ResponseError (772602: Unable to check user ban status/Unable to get updated ugc content | 774003: unable to update content file location)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = PublicUpdateContentFileLocation.create(
        body=body,
        channel_id=channel_id,
        content_id=content_id,
        user_id=user_id,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(PublicUpdateContentFileLocation)
async def public_update_content_file_location_async(
    body: ModelsUpdateFileLocationRequest,
    channel_id: str,
    content_id: str,
    user_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs,
):
    """Update content file location (PublicUpdateContentFileLocation)

    This endpoint should be used after calling generate upload url endpoint to commit the changes

    Properties:
        url: /ugc/v2/public/namespaces/{namespace}/users/{userId}/channels/{channelId}/contents/{contentId}/fileLocation

        method: PATCH

        tags: ["Public Content V2"]

        consumes: ["application/json", "application/octet-stream"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ModelsUpdateFileLocationRequest in body

        channel_id: (channelId) REQUIRED str in path

        content_id: (contentId) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

    Responses:
        200: OK - ModelsUpdateContentResponseV2 (Update content file location)

        400: Bad Request - ResponseError (774001: unable to read response body/unable to update file location)

        401: Unauthorized - ResponseError (20001: unauthorized access)

        403: Forbidden - ResponseError (772604: User has been banned to update content | 20013: insufficient permission)

        404: Not Found - ResponseError (774002: unable to update content file location: content not found)

        500: Internal Server Error - ResponseError (772602: Unable to check user ban status/Unable to get updated ugc content | 774003: unable to update content file location)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = PublicUpdateContentFileLocation.create(
        body=body,
        channel_id=channel_id,
        content_id=content_id,
        user_id=user_id,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(PublicUpdateContentV2)
def public_update_content_v2(
    body: ModelsUpdateContentRequestV2,
    channel_id: str,
    content_id: str,
    user_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs,
):
    """Update content (PublicUpdateContentV2)

    Update existing content

    Properties:
        url: /ugc/v2/public/namespaces/{namespace}/users/{userId}/channels/{channelId}/contents/{contentId}

        method: PATCH

        tags: ["Public Content V2"]

        consumes: ["application/json", "application/octet-stream"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ModelsUpdateContentRequestV2 in body

        channel_id: (channelId) REQUIRED str in path

        content_id: (contentId) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

    Responses:
        200: OK - ModelsUpdateContentResponseV2 (Content updated)

        400: Bad Request - ResponseError (772601: Malformed request)

        401: Unauthorized - ResponseError (20001: unauthorized access)

        403: Forbidden - ResponseError (772604: User has been banned to update content)

        404: Not Found - ResponseError (772603: Content not found)

        500: Internal Server Error - ResponseError (772602: Unable to check user ban status/Unable to get updated ugc content)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = PublicUpdateContentV2.create(
        body=body,
        channel_id=channel_id,
        content_id=content_id,
        user_id=user_id,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(PublicUpdateContentV2)
async def public_update_content_v2_async(
    body: ModelsUpdateContentRequestV2,
    channel_id: str,
    content_id: str,
    user_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs,
):
    """Update content (PublicUpdateContentV2)

    Update existing content

    Properties:
        url: /ugc/v2/public/namespaces/{namespace}/users/{userId}/channels/{channelId}/contents/{contentId}

        method: PATCH

        tags: ["Public Content V2"]

        consumes: ["application/json", "application/octet-stream"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ModelsUpdateContentRequestV2 in body

        channel_id: (channelId) REQUIRED str in path

        content_id: (contentId) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

    Responses:
        200: OK - ModelsUpdateContentResponseV2 (Content updated)

        400: Bad Request - ResponseError (772601: Malformed request)

        401: Unauthorized - ResponseError (20001: unauthorized access)

        403: Forbidden - ResponseError (772604: User has been banned to update content)

        404: Not Found - ResponseError (772603: Content not found)

        500: Internal Server Error - ResponseError (772602: Unable to check user ban status/Unable to get updated ugc content)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = PublicUpdateContentV2.create(
        body=body,
        channel_id=channel_id,
        content_id=content_id,
        user_id=user_id,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(UpdateContentShareCodeV2)
def update_content_share_code_v2(
    body: ModelsUpdateContentShareCodeRequest,
    channel_id: str,
    content_id: str,
    user_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs,
):
    """Update content share code (UpdateContentShareCodeV2)

    This endpoint is used to modify the shareCode of a content. However, this operation is restricted by default and requires the above permission to be granted to the User role.

    `shareCode` format should follows:
    Max length: 7
    Available characters: abcdefhkpqrstuxyz

    Properties:
        url: /ugc/v2/public/namespaces/{namespace}/users/{userId}/channels/{channelId}/contents/{contentId}/sharecode

        method: PATCH

        tags: ["Public Content V2"]

        consumes: ["application/json", "application/octet-stream"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ModelsUpdateContentShareCodeRequest in body

        channel_id: (channelId) REQUIRED str in path

        content_id: (contentId) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

    Responses:
        200: OK - ModelsCreateContentResponseV2 (Update content sharecode)

        400: Bad Request - ResponseError (772601: Malformed request | 772607: Unable to update ugc content: invalid shareCode format)

        401: Unauthorized - ResponseError (20001: unauthorized access)

        403: Forbidden - ResponseError (772604: User has been banned to update content | 20013: insufficient permission)

        404: Not Found - ResponseError (772603: Content not found)

        409: Conflict - ResponseError (772606: Share code already used)

        500: Internal Server Error - ResponseError (772602: Unable to check user ban status/Unable to get updated ugc content)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = UpdateContentShareCodeV2.create(
        body=body,
        channel_id=channel_id,
        content_id=content_id,
        user_id=user_id,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(UpdateContentShareCodeV2)
async def update_content_share_code_v2_async(
    body: ModelsUpdateContentShareCodeRequest,
    channel_id: str,
    content_id: str,
    user_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs,
):
    """Update content share code (UpdateContentShareCodeV2)

    This endpoint is used to modify the shareCode of a content. However, this operation is restricted by default and requires the above permission to be granted to the User role.

    `shareCode` format should follows:
    Max length: 7
    Available characters: abcdefhkpqrstuxyz

    Properties:
        url: /ugc/v2/public/namespaces/{namespace}/users/{userId}/channels/{channelId}/contents/{contentId}/sharecode

        method: PATCH

        tags: ["Public Content V2"]

        consumes: ["application/json", "application/octet-stream"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ModelsUpdateContentShareCodeRequest in body

        channel_id: (channelId) REQUIRED str in path

        content_id: (contentId) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

    Responses:
        200: OK - ModelsCreateContentResponseV2 (Update content sharecode)

        400: Bad Request - ResponseError (772601: Malformed request | 772607: Unable to update ugc content: invalid shareCode format)

        401: Unauthorized - ResponseError (20001: unauthorized access)

        403: Forbidden - ResponseError (772604: User has been banned to update content | 20013: insufficient permission)

        404: Not Found - ResponseError (772603: Content not found)

        409: Conflict - ResponseError (772606: Share code already used)

        500: Internal Server Error - ResponseError (772602: Unable to check user ban status/Unable to get updated ugc content)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = UpdateContentShareCodeV2.create(
        body=body,
        channel_id=channel_id,
        content_id=content_id,
        user_id=user_id,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(UpdateScreenshotsV2)
def update_screenshots_v2(
    body: ModelsUpdateScreenshotRequest,
    content_id: str,
    user_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs,
):
    """Update screenshot of content (UpdateScreenshotsV2)

    Maximum description length: 1024

    Properties:
        url: /ugc/v2/public/namespaces/{namespace}/users/{userId}/contents/{contentId}/screenshots

        method: PUT

        tags: ["Public Content V2"]

        consumes: ["application/json", "application/octet-stream"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ModelsUpdateScreenshotRequest in body

        content_id: (contentId) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

    Responses:
        200: OK - ModelsUpdateScreenshotResponse (Screenshot updated)

        400: Bad Request - ResponseError (772601: Malformed request)

        401: Unauthorized - ResponseError (20001: unauthorized access)

        403: Forbidden - ResponseError (772604: User has been banned to update content)

        404: Not Found - ResponseError (772603: Content not found)

        500: Internal Server Error - ResponseError (772602: Unable to check user ban status/Unable to get updated ugc content)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = UpdateScreenshotsV2.create(
        body=body,
        content_id=content_id,
        user_id=user_id,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(UpdateScreenshotsV2)
async def update_screenshots_v2_async(
    body: ModelsUpdateScreenshotRequest,
    content_id: str,
    user_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs,
):
    """Update screenshot of content (UpdateScreenshotsV2)

    Maximum description length: 1024

    Properties:
        url: /ugc/v2/public/namespaces/{namespace}/users/{userId}/contents/{contentId}/screenshots

        method: PUT

        tags: ["Public Content V2"]

        consumes: ["application/json", "application/octet-stream"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ModelsUpdateScreenshotRequest in body

        content_id: (contentId) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

    Responses:
        200: OK - ModelsUpdateScreenshotResponse (Screenshot updated)

        400: Bad Request - ResponseError (772601: Malformed request)

        401: Unauthorized - ResponseError (20001: unauthorized access)

        403: Forbidden - ResponseError (772604: User has been banned to update content)

        404: Not Found - ResponseError (772603: Content not found)

        500: Internal Server Error - ResponseError (772602: Unable to check user ban status/Unable to get updated ugc content)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = UpdateScreenshotsV2.create(
        body=body,
        content_id=content_id,
        user_id=user_id,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(UploadContentScreenshotV2)
def upload_content_screenshot_v2(
    body: ModelsCreateScreenshotRequest,
    content_id: str,
    user_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs,
):
    """Upload screenshots for content (UploadContentScreenshotV2)

    This endpoint used to request upload URL from content's screenshot.
    If *contentType* is not specified, it will use *fileExtension* value.
    Supported file extensions: pjp, jpg, jpeg, jfif, bmp, png.
    Maximum description length: 1024

    Properties:
        url: /ugc/v2/public/namespaces/{namespace}/users/{userId}/contents/{contentId}/screenshots

        method: POST

        tags: ["Public Content V2"]

        consumes: ["application/json", "application/octet-stream"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ModelsCreateScreenshotRequest in body

        content_id: (contentId) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

    Responses:
        201: Created - ModelsCreateScreenshotResponse (Screenshot uploaded)

        400: Bad Request - ResponseError (772601: Malformed request)

        401: Unauthorized - ResponseError (20001: unauthorized access)

        403: Forbidden - ResponseError (772604: User has been banned to update content)

        500: Internal Server Error - ResponseError (772602: Unable to check user ban status/Unable to get updated ugc content | 772605: Unable to save ugc content: failed generate upload URL)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = UploadContentScreenshotV2.create(
        body=body,
        content_id=content_id,
        user_id=user_id,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(UploadContentScreenshotV2)
async def upload_content_screenshot_v2_async(
    body: ModelsCreateScreenshotRequest,
    content_id: str,
    user_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs,
):
    """Upload screenshots for content (UploadContentScreenshotV2)

    This endpoint used to request upload URL from content's screenshot.
    If *contentType* is not specified, it will use *fileExtension* value.
    Supported file extensions: pjp, jpg, jpeg, jfif, bmp, png.
    Maximum description length: 1024

    Properties:
        url: /ugc/v2/public/namespaces/{namespace}/users/{userId}/contents/{contentId}/screenshots

        method: POST

        tags: ["Public Content V2"]

        consumes: ["application/json", "application/octet-stream"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ModelsCreateScreenshotRequest in body

        content_id: (contentId) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

    Responses:
        201: Created - ModelsCreateScreenshotResponse (Screenshot uploaded)

        400: Bad Request - ResponseError (772601: Malformed request)

        401: Unauthorized - ResponseError (20001: unauthorized access)

        403: Forbidden - ResponseError (772604: User has been banned to update content)

        500: Internal Server Error - ResponseError (772602: Unable to check user ban status/Unable to get updated ugc content | 772605: Unable to save ugc content: failed generate upload URL)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = UploadContentScreenshotV2.create(
        body=body,
        content_id=content_id,
        user_id=user_id,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: operation-init.j2

"""Auto-generated package that contains models used by the AccelByte Gaming Services Ugc Service."""

__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

from .admin_create_group import AdminCreateGroup
from .admin_delete_group import AdminDeleteGroup
from .admin_get_all_groups import AdminGetAllGroups
from .admin_get_group import AdminGetGroup
from .admin_get_group_contents import AdminGetGroupContents
from .admin_get_official_grou_23b467 import AdminGetOfficialGroupContentsV2
from .admin_get_user_group_co_73e55d import AdminGetUserGroupContentsV2
from .admin_update_group import AdminUpdateGroup
from .single_admin_delete_group import SingleAdminDeleteGroup
from .single_admin_get_all_groups import SingleAdminGetAllGroups
from .single_admin_get_group import SingleAdminGetGroup
from .single_admin_get_group__c6800e import SingleAdminGetGroupContents
from .single_admin_update_group import SingleAdminUpdateGroup



# Copyright (c) 2024 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: errors.j2

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

# AccelByte Gaming Services Ugc Service

from accelbyte_py_sdk.core import ApiError

ERROR_20001 = ApiError(code="20001", message="unauthorized access")
ERROR_20013 = ApiError(code="20013", message="insufficient permission")
ERROR_770100 = ApiError(
    code="770100", message="Malformed request/Invalid request body/channel do not exist"
)
ERROR_770102 = ApiError(
    code="770102",
    message="Unable to check user ban status/Unable to save ugc content: unable to get channel",
)
ERROR_770103 = ApiError(
    code="770103", message="Unable to save ugc content: shareCode exceed the limit"
)
ERROR_770104 = ApiError(code="770104", message="User has been banned to create content")
ERROR_770105 = ApiError(
    code="770105", message="Unable to save ugc content: failed generate upload URL"
)
ERROR_770106 = ApiError(code="770106", message="channel doesn't exist")
ERROR_770107 = ApiError(
    code="770107", message="Unable to update ugc content: invalid shareCode format"
)
ERROR_770200 = ApiError(code="770200", message="Content not found")
ERROR_770300 = ApiError(code="770300", message="ugc content not found")
ERROR_770301 = ApiError(
    code="770301", message="Unable to get ugc content/Unable to get creator"
)
ERROR_770303 = ApiError(code="770303", message="Failed generate download URL")
ERROR_770500 = ApiError(code="770500", message="Invalid request body")
ERROR_770502 = ApiError(code="770502", message="Unable to save channel")
ERROR_770503 = ApiError(
    code="770503", message="Invalid channel {ID}: should uuid without hypen"
)
ERROR_770504 = ApiError(code="770504", message="Channel already exist")
ERROR_770600 = ApiError(code="770600", message="Invalid request body")
ERROR_770602 = ApiError(code="770602", message="Unable to save channel")
ERROR_770603 = ApiError(code="770603", message="Channel was not found")
ERROR_770700 = ApiError(code="770700", message="Unable get user channels")
ERROR_770702 = ApiError(code="770702", message="invalid paging parameter")
ERROR_770800 = ApiError(
    code="770800",
    message="invalid paging parameter/max allowed number of tags is {maxTags}/invalid official parameter/invalid ishidden parameter",
)
ERROR_770801 = ApiError(
    code="770801", message="Unable to get ugc content: database/Unable to get creator"
)
ERROR_770803 = ApiError(code="770803", message="Failed generate download URL")
ERROR_770804 = ApiError(code="770804", message="invalid paging parameter")
ERROR_770805 = ApiError(
    code="770805", message="Unable to get ugc content: database error"
)
ERROR_770900 = ApiError(code="770900", message="invalid paging parameter")
ERROR_770901 = ApiError(
    code="770901",
    message="Unable to get ugc content: database error/Unable to get creator",
)
ERROR_770903 = ApiError(code="770903", message="Failed generate download URL")
ERROR_771000 = ApiError(
    code="771000",
    message="Malformed request/Content not found/Unable to update like status: content not found",
)
ERROR_771001 = ApiError(
    code="771001",
    message="unable to like content/Unable to update like status: database error",
)
ERROR_771003 = ApiError(
    code="771003", message="Unable to like content: too many request"
)
ERROR_771004 = ApiError(code="771004", message="invalid paging parameter")
ERROR_771006 = ApiError(
    code="771006", message="unable to get list of content like: database error"
)
ERROR_771100 = ApiError(code="771100", message="unable to parse isofficial param")
ERROR_771101 = ApiError(
    code="771101", message="Unable to get ugc content: database error"
)
ERROR_771103 = ApiError(code="771103", message="Unable to get total liked content")
ERROR_771200 = ApiError(code="771200", message="Malformed request")
ERROR_771201 = ApiError(
    code="771201", message="Unable to update follow status: database error"
)
ERROR_771300 = ApiError(code="771300", message="Unable to get creators: database error")
ERROR_771303 = ApiError(code="771303", message="Unable to get creators: database error")
ERROR_771304 = ApiError(code="771304", message="invalid paging parameter")
ERROR_771310 = ApiError(
    code="771310", message="Unable to get ugc content: database error"
)
ERROR_771311 = ApiError(code="771311", message="invalid paging parameter")
ERROR_771401 = ApiError(code="771401", message="Malformed request/Invalid request body")
ERROR_771402 = ApiError(code="771402", message="Unable to save ugc tag")
ERROR_771403 = ApiError(code="771403", message="Conflicted resource indentifier")
ERROR_771501 = ApiError(code="771501", message="invalid paging parameter")
ERROR_771502 = ApiError(code="771502", message="Unable get user tags")
ERROR_771601 = ApiError(code="771601", message="Creator not found")
ERROR_771701 = ApiError(code="771701", message="Malformed request/Invalid request body")
ERROR_771702 = ApiError(code="771702", message="Unable to save ugc type")
ERROR_771703 = ApiError(code="771703", message="Conflicted resource indentifier")
ERROR_771801 = ApiError(code="771801", message="invalid paging parameter")
ERROR_771802 = ApiError(code="771802", message="Unable get types")
ERROR_771901 = ApiError(code="771901", message="Malformed request/Invalid request body")
ERROR_771902 = ApiError(code="771902", message="Unable update types")
ERROR_771903 = ApiError(code="771903", message="Type not found")
ERROR_771904 = ApiError(code="771904", message="Proposed Type already exist")
ERROR_772002 = ApiError(code="772002", message="Unable delete tag")
ERROR_772003 = ApiError(code="772003", message="Tag not found")
ERROR_772004 = ApiError(code="772004", message="Unable delete type")
ERROR_772005 = ApiError(code="772005", message="Type not found")
ERROR_772101 = ApiError(code="772101", message="Malformed request/Invalid request body")
ERROR_772102 = ApiError(code="772102", message="Unable to create group")
ERROR_772201 = ApiError(code="772201", message="Malformed request/Invalid request body")
ERROR_772202 = ApiError(code="772202", message="Unable to update group")
ERROR_772203 = ApiError(code="772203", message="Group not found")
ERROR_772301 = ApiError(code="772301", message="invalid paging parameter")
ERROR_772302 = ApiError(code="772302", message="Unable get groups")
ERROR_772402 = ApiError(code="772402", message="Unable delete groups")
ERROR_772403 = ApiError(code="772403", message="Group not found")
ERROR_772501 = ApiError(code="772501", message="Unable to delete channel")
ERROR_772502 = ApiError(code="772502", message="Channel not found")
ERROR_772601 = ApiError(code="772601", message="Malformed request")
ERROR_772602 = ApiError(
    code="772602",
    message="Unable to check user ban status/Unable to get updated ugc content",
)
ERROR_772603 = ApiError(code="772603", message="Content not found")
ERROR_772604 = ApiError(code="772604", message="User has been banned to update content")
ERROR_772605 = ApiError(
    code="772605", message="Unable to save ugc content: failed generate upload URL"
)
ERROR_772606 = ApiError(code="772606", message="Share code already used")
ERROR_772607 = ApiError(
    code="772607", message="Unable to update ugc content: invalid shareCode format"
)
ERROR_772701 = ApiError(
    code="772701",
    message="Unable to delete content/Unable to update user liked count/Unable to delete like state/Unable to delete like state",
)
ERROR_772702 = ApiError(code="772702", message="Content not found")
ERROR_772801 = ApiError(code="772801", message="Malformed request/Invalid request body")
ERROR_772802 = ApiError(code="772802", message="Unable update tags")
ERROR_772803 = ApiError(code="772803", message="Tag not found")
ERROR_772804 = ApiError(code="772804", message="Proposed Tag already exist")
ERROR_772902 = ApiError(
    code="772902", message="Unable to add content download: database error"
)
ERROR_772903 = ApiError(
    code="772903", message="Unable to add content download: content not found"
)
ERROR_772904 = ApiError(
    code="772904", message="Unable to list content downloader: database error"
)
ERROR_772906 = ApiError(
    code="772906", message="Unable to add content download: too many request"
)
ERROR_773001 = ApiError(code="773001", message="Unable get group")
ERROR_773002 = ApiError(code="773002", message="Group not found")
ERROR_773101 = ApiError(code="773101", message="invalid paging parameter")
ERROR_773102 = ApiError(
    code="773102", message="Unable to get ugc content: database error"
)
ERROR_773103 = ApiError(code="773103", message="No group content was found")
ERROR_773200 = ApiError(code="773200", message="ugc content not found")
ERROR_773201 = ApiError(
    code="773201",
    message="Unable to get ugc content/Unable to get creator/Unable to get included group",
)
ERROR_773203 = ApiError(code="773203", message="Failed generate download URL")
ERROR_773301 = ApiError(code="773301", message="Unable to find all user group")
ERROR_773302 = ApiError(code="773302", message="Groups not found")
ERROR_773401 = ApiError(code="773401", message="Unable to get all user content")
ERROR_773402 = ApiError(code="773402", message="Content not found")
ERROR_773501 = ApiError(code="773501", message="Unable to delete channel")
ERROR_773502 = ApiError(code="773502", message="Channel not found")
ERROR_773601 = ApiError(
    code="773601",
    message="Unable to get all user contents/Unable to delete user states",
)
ERROR_773602 = ApiError(
    code="773602", message="user states are not found: content not found"
)
ERROR_773701 = ApiError(code="773701", message="Unable to get ugc content")
ERROR_773702 = ApiError(code="773702", message="ugc content not found")
ERROR_773801 = ApiError(code="773801", message="Invalid request body/Malformed request")
ERROR_773802 = ApiError(
    code="773802", message="Unable to update hide status: database error"
)
ERROR_773803 = ApiError(
    code="773803", message="Unable to update hide status: content not found"
)
ERROR_773804 = ApiError(
    code="773804", message="Unable to save ugc content: failed generate upload URL"
)
ERROR_773805 = ApiError(
    code="773805",
    message="Unable to save ugc content preview: failed generate upload URL",
)
ERROR_773900 = ApiError(code="773900", message="Malformed request/Invalid request body")
ERROR_773901 = ApiError(
    code="773901", message="Unable to get ugc content: database/Unable to get creator"
)
ERROR_773902 = ApiError(code="773902", message="Failed generate download URL")
ERROR_774001 = ApiError(
    code="774001", message="unable to read response body/unable to update file location"
)
ERROR_774002 = ApiError(
    code="774002", message="unable to update content file location: content not found"
)
ERROR_774003 = ApiError(code="774003", message="unable to update content file location")
ERROR_774004 = ApiError(code="774004", message="ugc content not found")
ERROR_774005 = ApiError(code="774005", message="unable to get ugc content")
ERROR_774101 = ApiError(code="774101", message="ugc content not found")
ERROR_774102 = ApiError(code="774102", message="version not found")
ERROR_774103 = ApiError(
    code="774103",
    message="unable to get ugc content/content cannot be restored using the current content version",
)
ERROR_774201 = ApiError(code="774201", message="Invalid request body")
ERROR_774202 = ApiError(code="774202", message="Unable to save config")
ERROR_774204 = ApiError(code="774204", message="invalid paging parameter")
ERROR_774205 = ApiError(code="774205", message="Unable to get configs")
ERROR_774301 = ApiError(code="774301", message="invalid paging parameter")
ERROR_774302 = ApiError(code="774302", message="unable to get staging content")
ERROR_774303 = ApiError(code="774303", message="unable to generate presigned URL")
ERROR_774401 = ApiError(code="774401", message="staging content not found")
ERROR_774402 = ApiError(code="774402", message="unable to get staging content")
ERROR_774403 = ApiError(code="774403", message="unable to generate presigned URL")
ERROR_774405 = ApiError(code="774405", message="Invalid request body")
ERROR_774406 = ApiError(code="774406", message="staging content not found")
ERROR_774407 = ApiError(code="774407", message="unable to approve staging content")
ERROR_774408 = ApiError(
    code="774408", message="nable to save ugc content: shareCode exceed the limit"
)
ERROR_774411 = ApiError(code="774411", message="Invalid request body")
ERROR_774412 = ApiError(code="774412", message="user has been banned to update content")
ERROR_774413 = ApiError(code="774413", message="staging content not found")
ERROR_774414 = ApiError(code="774414", message="unable to update staging content")
ERROR_774415 = ApiError(code="774415", message="unable to generate presigned URL")
ERROR_774417 = ApiError(code="774417", message="staging content not found")
ERROR_774418 = ApiError(code="774418", message="unable to delete staging content")



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: wrapper-init.j2

"""Auto-generated package that contains models used by the AccelByte Gaming Services Ugc Service."""

__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

from ._admin_channel import admin_create_channel
from ._admin_channel import admin_create_channel_async
from ._admin_channel import admin_delete_channel
from ._admin_channel import admin_delete_channel_async
from ._admin_channel import admin_get_channel
from ._admin_channel import admin_get_channel_async
from ._admin_channel import admin_update_channel
from ._admin_channel import admin_update_channel_async
from ._admin_channel import single_admin_delete_channel
from ._admin_channel import single_admin_delete_channel_async
from ._admin_channel import single_admin_get_channel
from ._admin_channel import single_admin_get_channel_async
from ._admin_channel import single_admin_update_channel
from ._admin_channel import single_admin_update_channel_async

from ._admin_config import admin_get_configs
from ._admin_config import admin_get_configs_async
from ._admin_config import admin_update_config
from ._admin_config import admin_update_config_async

from ._admin_content import admin_delete_content
from ._admin_content import admin_delete_content_async
from ._admin_content import admin_delete_content_screenshot
from ._admin_content import admin_delete_content_screenshot_async
from ._admin_content import admin_download_content_preview
from ._admin_content import admin_download_content_preview_async
from ._admin_content import admin_get_content
from ._admin_content import admin_get_content_async
from ._admin_content import admin_get_content_bulk
from ._admin_content import admin_get_content_bulk_async
from ._admin_content import admin_get_content_bulk_by_share_codes
from ._admin_content import admin_get_content_bulk_by_share_codes_async
from ._admin_content import admin_get_specific_content
from ._admin_content import admin_get_specific_content_async
from ._admin_content import admin_get_user_content_by_share_code
from ._admin_content import admin_get_user_content_by_share_code_async
from ._admin_content import admin_hide_user_content
from ._admin_content import admin_hide_user_content_async
from ._admin_content import admin_search_channel_specific_content
from ._admin_content import admin_search_channel_specific_content_async
from ._admin_content import admin_search_content
from ._admin_content import admin_search_content_async
from ._admin_content import admin_update_content_direct
from ._admin_content import admin_update_content_direct_async
from ._admin_content import admin_update_content_s3
from ._admin_content import admin_update_content_s3_async
from ._admin_content import admin_update_content_s3_by_share_code
from ._admin_content import admin_update_content_s3_by_share_code_async
from ._admin_content import admin_update_screenshots
from ._admin_content import admin_update_screenshots_async
from ._admin_content import admin_upload_content_direct
from ._admin_content import admin_upload_content_direct_async
from ._admin_content import admin_upload_content_s3
from ._admin_content import admin_upload_content_s3_async
from ._admin_content import admin_upload_content_screenshot
from ._admin_content import admin_upload_content_screenshot_async
from ._admin_content import delete_content_by_share_code
from ._admin_content import delete_content_by_share_code_async
from ._admin_content import list_content_versions
from ._admin_content import list_content_versions_async
from ._admin_content import rollback_content_version
from ._admin_content import rollback_content_version_async
from ._admin_content import single_admin_delete_content
from ._admin_content import single_admin_delete_content_async
from ._admin_content import single_admin_get_content
from ._admin_content import single_admin_get_content_async
from ._admin_content import single_admin_update_content_direct
from ._admin_content import single_admin_update_content_direct_async
from ._admin_content import single_admin_update_content_s3
from ._admin_content import single_admin_update_content_s3_async

from ._admin_content_v2 import admin_bulk_get_content_by_i_ds_v2
from ._admin_content_v2 import admin_bulk_get_content_by_i_ds_v2_async
from ._admin_content_v2 import admin_copy_content
from ._admin_content_v2 import admin_copy_content_async
from ._admin_content_v2 import admin_create_content_v2
from ._admin_content_v2 import admin_create_content_v2_async
from ._admin_content_v2 import admin_delete_content_by_share_code_v2
from ._admin_content_v2 import admin_delete_content_by_share_code_v2_async
from ._admin_content_v2 import admin_delete_content_screenshot_v2
from ._admin_content_v2 import admin_delete_content_screenshot_v2_async
from ._admin_content_v2 import admin_delete_official_content_v2
from ._admin_content_v2 import admin_delete_official_content_v2_async
from ._admin_content_v2 import admin_delete_user_content_v2
from ._admin_content_v2 import admin_delete_user_content_v2_async
from ._admin_content_v2 import admin_generate_official_content_upload_urlv2
from ._admin_content_v2 import admin_generate_official_content_upload_urlv2_async
from ._admin_content_v2 import admin_generate_user_content_upload_urlv2
from ._admin_content_v2 import admin_generate_user_content_upload_urlv2_async
from ._admin_content_v2 import admin_get_content_bulk_by_share_codes_v2
from ._admin_content_v2 import admin_get_content_bulk_by_share_codes_v2_async
from ._admin_content_v2 import admin_get_content_by_channel_idv2
from ._admin_content_v2 import admin_get_content_by_channel_idv2_async
from ._admin_content_v2 import admin_get_content_by_content_idv2
from ._admin_content_v2 import admin_get_content_by_content_idv2_async
from ._admin_content_v2 import admin_get_content_by_share_code_v2
from ._admin_content_v2 import admin_get_content_by_share_code_v2_async
from ._admin_content_v2 import admin_get_content_by_user_idv2
from ._admin_content_v2 import admin_get_content_by_user_idv2_async
from ._admin_content_v2 import admin_list_content_v2
from ._admin_content_v2 import admin_list_content_v2_async
from ._admin_content_v2 import admin_update_content_by_share_code_v2
from ._admin_content_v2 import admin_update_content_by_share_code_v2_async
from ._admin_content_v2 import admin_update_content_hide_status_v2
from ._admin_content_v2 import admin_update_content_hide_status_v2_async
from ._admin_content_v2 import admin_update_official_content_file_location
from ._admin_content_v2 import admin_update_official_content_file_location_async
from ._admin_content_v2 import admin_update_official_content_v2
from ._admin_content_v2 import admin_update_official_content_v2_async
from ._admin_content_v2 import admin_update_screenshots_v2
from ._admin_content_v2 import admin_update_screenshots_v2_async
from ._admin_content_v2 import admin_update_user_content_file_location
from ._admin_content_v2 import admin_update_user_content_file_location_async
from ._admin_content_v2 import admin_update_user_content_v2
from ._admin_content_v2 import admin_update_user_content_v2_async
from ._admin_content_v2 import admin_upload_content_screenshot_v2
from ._admin_content_v2 import admin_upload_content_screenshot_v2_async
from ._admin_content_v2 import list_content_versions_v2
from ._admin_content_v2 import list_content_versions_v2_async
from ._admin_content_v2 import rollback_content_version_v2
from ._admin_content_v2 import rollback_content_version_v2_async

from ._admin_group import admin_create_group
from ._admin_group import admin_create_group_async
from ._admin_group import admin_delete_group
from ._admin_group import admin_delete_group_async
from ._admin_group import admin_get_all_groups
from ._admin_group import admin_get_all_groups_async
from ._admin_group import admin_get_group
from ._admin_group import admin_get_group_async
from ._admin_group import admin_get_group_contents
from ._admin_group import admin_get_group_contents_async
from ._admin_group import admin_get_official_group_contents_v2
from ._admin_group import admin_get_official_group_contents_v2_async
from ._admin_group import admin_get_user_group_contents_v2
from ._admin_group import admin_get_user_group_contents_v2_async
from ._admin_group import admin_update_group
from ._admin_group import admin_update_group_async
from ._admin_group import single_admin_delete_group
from ._admin_group import single_admin_delete_group_async
from ._admin_group import single_admin_get_all_groups
from ._admin_group import single_admin_get_all_groups_async
from ._admin_group import single_admin_get_group
from ._admin_group import single_admin_get_group_async
from ._admin_group import single_admin_get_group_contents
from ._admin_group import single_admin_get_group_contents_async
from ._admin_group import single_admin_update_group
from ._admin_group import single_admin_update_group_async

from ._admin_staging_content import admin_approve_staging_content
from ._admin_staging_content import admin_approve_staging_content_async
from ._admin_staging_content import admin_get_staging_content_by_id
from ._admin_staging_content import admin_get_staging_content_by_id_async
from ._admin_staging_content import admin_list_staging_contents
from ._admin_staging_content import admin_list_staging_contents_async
from ._admin_staging_content import admin_list_user_staging_contents
from ._admin_staging_content import admin_list_user_staging_contents_async

from ._admin_tag import admin_create_tag
from ._admin_tag import admin_create_tag_async
from ._admin_tag import admin_delete_tag
from ._admin_tag import admin_delete_tag_async
from ._admin_tag import admin_get_tag
from ._admin_tag import admin_get_tag_async
from ._admin_tag import admin_update_tag
from ._admin_tag import admin_update_tag_async

from ._admin_type import admin_create_type
from ._admin_type import admin_create_type_async
from ._admin_type import admin_delete_type
from ._admin_type import admin_delete_type_async
from ._admin_type import admin_get_type
from ._admin_type import admin_get_type_async
from ._admin_type import admin_update_type
from ._admin_type import admin_update_type_async

from ._anonymization import admin_delete_all_user_channels
from ._anonymization import admin_delete_all_user_channels_async
from ._anonymization import admin_delete_all_user_contents
from ._anonymization import admin_delete_all_user_contents_async
from ._anonymization import admin_delete_all_user_group
from ._anonymization import admin_delete_all_user_group_async
from ._anonymization import admin_delete_all_user_states
from ._anonymization import admin_delete_all_user_states_async
from ._anonymization import delete_all_user_channel
from ._anonymization import delete_all_user_channel_async
from ._anonymization import delete_all_user_contents
from ._anonymization import delete_all_user_contents_async
from ._anonymization import delete_all_user_group
from ._anonymization import delete_all_user_group_async
from ._anonymization import delete_all_user_states
from ._anonymization import delete_all_user_states_async

from ._public_channel import delete_channel
from ._public_channel import delete_channel_async
from ._public_channel import get_channels
from ._public_channel import get_channels_async
from ._public_channel import public_create_channel
from ._public_channel import public_create_channel_async
from ._public_channel import update_channel
from ._public_channel import update_channel_async

from ._public_content_legacy import create_content_direct
from ._public_content_legacy import create_content_direct_async
from ._public_content_legacy import create_content_s3
from ._public_content_legacy import create_content_s3_async
from ._public_content_legacy import delete_content
from ._public_content_legacy import delete_content_async
from ._public_content_legacy import delete_content_screenshot
from ._public_content_legacy import delete_content_screenshot_async
from ._public_content_legacy import public_delete_content_by_share_code
from ._public_content_legacy import public_delete_content_by_share_code_async
from ._public_content_legacy import public_download_content_by_content_id
from ._public_content_legacy import public_download_content_by_content_id_async
from ._public_content_legacy import public_download_content_by_share_code
from ._public_content_legacy import public_download_content_by_share_code_async
from ._public_content_legacy import public_download_content_preview
from ._public_content_legacy import public_download_content_preview_async
from ._public_content_legacy import public_get_content_bulk
from ._public_content_legacy import public_get_content_bulk_async
from ._public_content_legacy import public_get_content_bulk_by_share_codes
from ._public_content_legacy import public_get_content_bulk_by_share_codes_async
from ._public_content_legacy import public_get_user_content
from ._public_content_legacy import public_get_user_content_async
from ._public_content_legacy import public_search_content
from ._public_content_legacy import public_search_content_async
from ._public_content_legacy import public_update_content_by_share_code
from ._public_content_legacy import public_update_content_by_share_code_async
from ._public_content_legacy import search_channel_specific_content
from ._public_content_legacy import search_channel_specific_content_async
from ._public_content_legacy import update_content_direct
from ._public_content_legacy import update_content_direct_async
from ._public_content_legacy import update_content_s3
from ._public_content_legacy import update_content_s3_async
from ._public_content_legacy import update_content_share_code
from ._public_content_legacy import update_content_share_code_async
from ._public_content_legacy import update_screenshots
from ._public_content_legacy import update_screenshots_async
from ._public_content_legacy import upload_content_screenshot
from ._public_content_legacy import upload_content_screenshot_async

from ._public_content_v2 import delete_content_screenshot_v2
from ._public_content_v2 import delete_content_screenshot_v2_async
from ._public_content_v2 import public_bulk_get_content_by_idv2
from ._public_content_v2 import public_bulk_get_content_by_idv2_async
from ._public_content_v2 import public_create_content_v2
from ._public_content_v2 import public_create_content_v2_async
from ._public_content_v2 import public_delete_content_by_share_code_v2
from ._public_content_v2 import public_delete_content_by_share_code_v2_async
from ._public_content_v2 import public_delete_content_v2
from ._public_content_v2 import public_delete_content_v2_async
from ._public_content_v2 import public_generate_content_upload_urlv2
from ._public_content_v2 import public_generate_content_upload_urlv2_async
from ._public_content_v2 import public_get_content_bulk_by_share_codes_v2
from ._public_content_v2 import public_get_content_bulk_by_share_codes_v2_async
from ._public_content_v2 import public_get_content_by_channel_idv2
from ._public_content_v2 import public_get_content_by_channel_idv2_async
from ._public_content_v2 import public_get_content_by_idv2
from ._public_content_v2 import public_get_content_by_idv2_async
from ._public_content_v2 import public_get_content_by_share_code_v2
from ._public_content_v2 import public_get_content_by_share_code_v2_async
from ._public_content_v2 import public_get_content_by_user_idv2
from ._public_content_v2 import public_get_content_by_user_idv2_async
from ._public_content_v2 import public_list_content_v2
from ._public_content_v2 import public_list_content_v2_async
from ._public_content_v2 import public_update_content_by_share_code_v2
from ._public_content_v2 import public_update_content_by_share_code_v2_async
from ._public_content_v2 import public_update_content_file_location
from ._public_content_v2 import public_update_content_file_location_async
from ._public_content_v2 import public_update_content_v2
from ._public_content_v2 import public_update_content_v2_async
from ._public_content_v2 import update_content_share_code_v2
from ._public_content_v2 import update_content_share_code_v2_async
from ._public_content_v2 import update_screenshots_v2
from ._public_content_v2 import update_screenshots_v2_async
from ._public_content_v2 import upload_content_screenshot_v2
from ._public_content_v2 import upload_content_screenshot_v2_async

from ._public_creator import public_get_creator
from ._public_creator import public_get_creator_async
from ._public_creator import public_search_creator
from ._public_creator import public_search_creator_async

from ._public_download_count_legacy import add_download_count
from ._public_download_count_legacy import add_download_count_async

from ._public_download_count_v2 import public_add_download_count_v2
from ._public_download_count_v2 import public_add_download_count_v2_async
from ._public_download_count_v2 import public_list_content_downloader_v2
from ._public_download_count_v2 import public_list_content_downloader_v2_async

from ._public_follow import get_followed_content
from ._public_follow import get_followed_content_async
from ._public_follow import get_followed_users
from ._public_follow import get_followed_users_async
from ._public_follow import get_public_followers
from ._public_follow import get_public_followers_async
from ._public_follow import get_public_following
from ._public_follow import get_public_following_async
from ._public_follow import update_user_follow_status
from ._public_follow import update_user_follow_status_async

from ._public_group import create_group
from ._public_group import create_group_async
from ._public_group import delete_group
from ._public_group import delete_group_async
from ._public_group import get_group
from ._public_group import get_group_async
from ._public_group import get_group_content
from ._public_group import get_group_content_async
from ._public_group import get_groups
from ._public_group import get_groups_async
from ._public_group import public_get_group_contents_v2
from ._public_group import public_get_group_contents_v2_async
from ._public_group import update_group
from ._public_group import update_group_async

from ._public_like_legacy import get_liked_content
from ._public_like_legacy import get_liked_content_async
from ._public_like_legacy import update_content_like_status
from ._public_like_legacy import update_content_like_status_async

from ._public_like_v2 import public_list_content_like_v2
from ._public_like_v2 import public_list_content_like_v2_async
from ._public_like_v2 import update_content_like_status_v2
from ._public_like_v2 import update_content_like_status_v2_async

from ._public_staging_content import delete_user_staging_content_by_id
from ._public_staging_content import delete_user_staging_content_by_id_async
from ._public_staging_content import get_user_staging_content_by_id
from ._public_staging_content import get_user_staging_content_by_id_async
from ._public_staging_content import list_user_staging_contents
from ._public_staging_content import list_user_staging_contents_async
from ._public_staging_content import update_staging_content
from ._public_staging_content import update_staging_content_async

from ._public_tag import get_tag
from ._public_tag import get_tag_async

from ._public_type import get_type
from ._public_type import get_type_async



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: operation-init.j2

"""Auto-generated package that contains models used by the AccelByte Gaming Services Ugc Service."""

__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

from .create_content_direct import CreateContentDirect
from .create_content_s3 import CreateContentS3
from .delete_content import DeleteContent
from .delete_content_screenshot import DeleteContentScreenshot
from .public_delete_content_b_e67ae8 import PublicDeleteContentByShareCode
from .public_download_content_511956 import PublicDownloadContentByContentID
from .public_download_content_2d5c80 import PublicDownloadContentByShareCode
from .public_download_content_32df1f import PublicDownloadContentPreview
from .public_get_content_bulk import PublicGetContentBulk
from .public_get_content_bulk_382fb9 import PublicGetContentBulkByShareCodes
from .public_get_user_content import PublicGetUserContent
from .public_search_content import PublicSearchContent
from .public_update_content_b_7f10f2 import PublicUpdateContentByShareCode
from .search_channel_specific_10d5e8 import SearchChannelSpecificContent
from .update_content_direct import UpdateContentDirect
from .update_content_s3 import UpdateContentS3
from .update_content_share_code import UpdateContentShareCode
from .update_screenshots import UpdateScreenshots
from .upload_content_screenshot import UploadContentScreenshot
